@@ -8,6 +8,7 @@ from declic import Group
 from outflow.core.generic.metaclasses import Singleton
 from outflow.core.generic.string import to_camel_case, to_snake_case
 from outflow.core.library.tasks import PipelineArgs
+from outflow.core.target import Target
 from outflow.core.tasks.task import Task
 
 logger = logging.getLogger(__name__)
@@ -158,11 +159,15 @@ class Command(Group, metaclass=Singleton):
                 def setup_tasks(self):
                     pipeline_args = PipelineArgs()
 
+                    @Target.output(
+                        "None"
+                    )  # workaround to avoid automatic output declaration
                     @Task.as_task(name=subclass_name, with_self=with_task_context)
                     def InnerTask(*args, **kwargs):
-                        # filter task kwargs using subcommand keywords
+                        self.outputs = {}  # revert workaround to have normal behaviour
                         if args:
                             kwargs.update({"self": args[0]})
+                        # filter task kwargs using subcommand keywords
                         return self.generic_callback(kwargs, callback_or_command_class)
 
                     task = InnerTask()
