@@ -10,16 +10,20 @@ from outflow.core.target import Target
 from outflow.core.tasks.task import Task
 
 
-@Task.as_task(with_self=True)
-def PipelineArgs(self):
-    pipeline_args = {}
-    self.outputs = {}
+class PipelineArgs(Task):
+    def __init__(self, *args, **kwargs):
+        self.with_context = True
+        super().__init__(*args, auto_outputs=False, **kwargs)
 
-    # update target outputs and returned value using the pipeline args
-    for key in vars(self.context.args):
-        self.outputs.update({key: Target(name=key)})
-        pipeline_args[key] = getattr(self.context.args, key)
-    return pipeline_args
+    def run(self):
+        pipeline_args = {}
+        self.outputs = {}
+
+        # update target outputs and returned value using the pipeline args
+        for key in vars(self.context.args):
+            self.outputs.update({key: Target(name=key)})
+            pipeline_args[key] = getattr(self.context.args, key)
+        return pipeline_args
 
 
 @Task.as_task(with_self=False)
