@@ -13,7 +13,6 @@ from outflow.core.plugin import Plugin
 
 
 class Pipeline:
-
     system_arguments = {
         "config": (
             ["--config"],
@@ -56,15 +55,27 @@ class Pipeline:
             ["-L", "--local-mode"],
             {"help": "Force local mode", "action": "store_true"},
         ),
-    }
-
-    base_arguments = {
-        "dry_run": (
-            ["--dry_run"],
-            {"help": "Run the pipeline without the database", "action": "store_true"},
+        "static_typecheck": (
+            ["--static-typecheck"],
+            {
+                "help": "Use the static typechecker backend to validate the given command",
+                "action": "store_true",
+            },
         ),
     }
 
+    base_arguments = (
+        {  # TODO test underscore (just for information) and switch to caret
+            "dry_run": (
+                ["--dry_run"],
+                {
+                    "help": "Run the pipeline without the database",
+                    "action": "store_true",
+                },
+            ),
+        }
+    )
+
     def __init__(
         self,
         *,
@@ -124,6 +135,8 @@ class Pipeline:
         logger.debug(f"Config loaded: {pipeline_config}")
 
         pipeline_config["local_mode"] = system_args.local_mode
+        if system_args.static_typecheck:
+            pipeline_config["backend"] = "static_typechecker"
 
         self.load_plugins()
         self.load_backends()
@@ -135,7 +148,7 @@ class Pipeline:
             Plugin.load(plugin_name)
 
     def load_backends(self):
-        from outflow.core.backend import Backend as DefaultBackend
+        from outflow.core.backends.backend import Backend as DefaultBackend
         from outflow.core.pipeline import settings
 
         self.backends = {"default": DefaultBackend}
@@ -207,7 +220,12 @@ class Pipeline:
             return 0
 
         backend_name = config.get("backend", "default")
-        Backend = self.backends.get(backend_name, self.backends["default"])
+        Backend = self.backends.get(backend_name)
+        if Backend is None:
+            raise ModuleNotFoundError(
+                f"Could not find backend {backend_name}, "
+                "please check that it is correctly imported"
+            )
         backend = Backend(context=self.context)
 
         try:
