@@ -15,6 +15,9 @@ PLUGINS = [
     "outflow.management",
 ]
 
-BACKENDS = {"ray": "outflow.ray.backend"}
+BACKENDS = {
+    "ray": "outflow.ray.backend",
+    "static_typechecker": "outflow.core.backends.static_typechecker",
+}
 
 ROOT_COMMAND_CLASS = RootCommand
