@@ -41,7 +41,7 @@ class Plugin:
             importlib.import_module(name)
             logger.debug(f"Module {name} successfully imported")
             return True
-        except ImportError:
+        except ImportError as ie:
             if plugin_name != "outflow.management":
                 logger.warning(
                     "Cannot import module {0} for plugin {1}:".format(
@@ -49,6 +49,7 @@ class Plugin:
                         plugin_name,
                     )
                 )
+            logger.debug(ie)
             return False
 
     @staticmethod
