@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 class Results:
-    """Expose a read-only dict for results
-    """
+    """Expose a read-only dict for results"""
 
     def __init__(self):
         # store the results
