@@ -50,6 +50,8 @@ class BaseTask(metaclass=TaskMeta):
 
     @classmethod
     def add_parameter(cls, target):
+        if target.name in cls.inputs:
+            del cls.inputs[target.name]
         cls.parameters.update({target.name: target})
 
     @property
