@@ -1,9 +1,8 @@
 # -*- coding: utf-8 -*-
-from ray._raylet import ObjectRef
 
 from outflow.core.logging import logger
 from outflow.core.target import TargetException
-from outflow.ray.results import Results as RayResults
+from outflow.core.results import Results
 
 
 class TaskManager:
@@ -13,7 +12,7 @@ class TaskManager:
 
     def __init__(self):
         # to avoid reprocessing, store a reference of each task result for each already visited graph node
-        self.results = RayResults()
+        self.results = Results()
 
     def compute(self, workflow):
 
@@ -57,23 +56,28 @@ class TaskManager:
         # if not, store the reference of the task result dict
         logger.debug(f"Running task {task.name}")
 
-        task_return_value = task(**task_inputs)
-
-        if task_return_value is not None and not isinstance(
-            task_return_value, ObjectRef
-        ):
-            if not isinstance(task_return_value, dict):
-                if len(task.outputs) > 1:
-                    raise TargetException(
-                        f"Task {task.name} must return a dictionary since it has defined more than one output target"
-                    )
-                else:
-                    task_return_value = {
-                        next(iter(task.outputs)): task_return_value
-                    }  # get first and only item in dictionary task.outputs
+        task_return_value = self.run(task, task_inputs)
+        task_return_value = self.post_process(task, task_return_value)
 
         self.results._set(task.id, task_return_value)
 
         # repeat the process with task child
         for child in task.children:
             self.add(child)
+
+    def run(self, task, task_inputs):
+        return task(**task_inputs)
+
+    def post_process(self, task, task_return_value):
+        post_processed = task_return_value
+        if not isinstance(task_return_value, dict):
+            if len(task.outputs) > 1:
+                raise TargetException(
+                    f"Task {task.name} must return a dictionary since it has defined more than one output target"
+                )
+            elif len(task.outputs) == 1:
+                post_processed = {
+                    next(iter(task.outputs)): task_return_value
+                }  # get first and only item in dictionary task.outputs
+
+        return post_processed
