@@ -2,13 +2,14 @@
 import argparse
 import importlib
 import os
-import sys
+import tempfile
 from pathlib import Path
 
 import outflow.core.db.alembic as outflow_alembic
 from alembic import command
-from alembic.config import Config
+from alembic.config import Config, main
 from outflow.core.command import Command, argument
+from outflow.core.db import DeclarativeBases
 from outflow.core.logging import logger
 from outflow.core.plugin import Plugin
 from outflow.core.tasks.task import Task
@@ -17,7 +18,57 @@ from sqlalchemy import UniqueConstraint
 from .management import Management
 
 
-@Management.subcommand()
+def generate_alembic_ini_file(alembic_ini_path, alembic_config):
+    with open(alembic_ini_path, "w") as ini_file:
+        ini_file.write("[alembic]\n")
+        for key, value in alembic_config["main_options"].items():
+            ini_file.write(f"{key} = {value}\n")
+
+        for key, value in alembic_config["admin"].items():
+            ini_file.write(f"{key} = {value}\n")
+
+
+def get_alembic_config(db_label, pipeline_context, plugin=None):
+
+    version_locations = []
+    for plugin_name in pipeline_context.settings.PLUGINS:
+        location = Plugin.get_path(plugin_name) / "models" / "versions" / db_label
+        if Path(location).is_dir():
+            version_locations.append(location.absolute().as_posix())
+
+    alembic_path = Path(outflow_alembic.__file__).parent.absolute().as_posix()
+
+    config = {
+        "main_options": {
+            "script_location": alembic_path,
+            "version_locations": " ".join(version_locations),
+            "output_encoding": "utf-8",
+        },
+        "attributes": {
+            "connection": pipeline_context.databases[db_label].admin_connection,
+            "login_info": pipeline_context.config["databases"][db_label],
+            "Base": DeclarativeBases[db_label],
+            "db_label": db_label,
+        },
+        "admin": {
+            "sqlalchemy.url": pipeline_context.databases[db_label]._generate_url(
+                admin=True
+            )
+        },
+        "post_write_hooks": {
+            "hooks": "black",
+            "black.type": "console_scripts",
+            "black.entrypoint": "black",
+        },
+    }
+
+    if plugin:
+        config["attributes"]["plugin"] = plugin
+
+    return config
+
+
+@Management.subcommand(invokable=False)
 class Db(Command):
     """
     Root command of the subcommands managing the database
@@ -59,7 +110,7 @@ class ExecuteSQL(Command):
         Executed to clear the database.
         """
 
-        @Task.as_task(with_context=True)
+        @Task.as_task(with_self=True)
         def ExecuteCli(self: Task):
             """
             to execute a script on the outflow database from the command line.
@@ -92,46 +143,87 @@ class ExecuteSQL(Command):
         return ExecuteCli()
 
 
-# @Db.subcommand(with_task_context=True, allow_extra_args=True)
-# @argument("command", type=str, help=""" The command to give to alembic. """, )
-# def alembic(self: Task):
-#
-#     print(self.context)
-#
-#     TEMP_DIR = tempfile.gettempdir()
-#
-#     version_locations = list()
-#     for plugin_name in self.context.settings.PLUGINS:
-#         location = Plugin.get_path(plugin_name, "models", "versions")
-#         if Path(location).is_dir():
-#             version_locations.append(location)
-#
-#     alembic_path = Plugin.get_path("outflow", "management", "alembic")
-#
-#     with open(Path(TEMP_DIR) / "alembic.ini", "w") as f:
-#         f.truncate()
-#         f.write("[alembic]\n")
-#         f.write(f'script_location = {alembic_path}\n')
-#         f.write(f'version_locations = {" ".join(version_locations)}\n')
-#         f.write(
-#             f"sqlalchemy.url = {self.context.db._generate_url(admin=True)}\n"
-#         )
-#         f.write("output_encoding = utf-8\n")
-#
-#     alembicArgs = [
-#         "-c",
-#         str(Path(TEMP_DIR) / "alembic.ini"),
-#         sys.argv[3],
-#         *sys.argv[4:],
-#     ]
-#
-#     main(argv=alembicArgs)
-#
-#     return {}
-# TODO use the future ShellTask to do this instead of calling alembic entrypoint
+@Db.subcommand(with_task_context=True, allow_extra_args=True)
+@argument("-d", "--db_label", type=str, default="default")
+@argument(
+    "command",
+    type=str,
+    help=""" The command to give to alembic. """,
+)
+def alembic(self: Task):
+    db_label = self.context.args.db_label
+
+    alembic_config = get_alembic_config(db_label, self.context)
+
+    with tempfile.TemporaryDirectory() as tmp_dir_path:
+        alembic_ini_path = (Path(tmp_dir_path) / "alembic.ini").resolve()
+        generate_alembic_ini_file(alembic_ini_path, alembic_config)
+
+        alembic_args = [
+            "-c",
+            alembic_ini_path.as_posix(),
+            *self.context.extra_args,
+        ]
+
+        main(argv=alembic_args)
+
+
+def migrate(task, migration_func):
+    revision = task.context.args.revision
+
+    if revision is None:
+        raise Exception("Missing required argument : revision")
+
+    db_label = task.context.args.db_label
+    version_locations = list()
+
+    for plugin_name in task.context.settings.PLUGINS:
+        location = Plugin.get_path(plugin_name) / "models" / "versions" / db_label
+        if location.is_dir():
+            for model_file in (Plugin.get_path(plugin_name) / "models").glob(
+                "[!_]*.py"
+            ):
+                db = getattr(
+                    importlib.import_module(plugin_name).models,
+                    model_file.name.split(".")[0],
+                ).Base
+                if db == DeclarativeBases[db_label]:
+                    version_locations.append(location.resolve().as_posix())
+
+    alembic_config_dict = get_alembic_config(db_label, task.context)
+    cfg = Config()
+
+    for key, value in alembic_config_dict["main_options"].items():
+        cfg.set_main_option(key, value)
+
+    for key, value in alembic_config_dict["attributes"].items():
+        cfg.attributes[key] = value
+
+    logger.info("Calling alembic")
+
+    migration_func(cfg, revision)
 
 
 @Db.subcommand(with_task_context=True)
+@argument("--db_label", "-d", type=str, default="default")
+@argument(
+    "revision",
+    type=str,
+    default=None,
+    nargs="?",
+    help="""
+          The revision of the database to switch on. Can be either 'head' for
+          the last revision, or an unique identifier of the revision (for
+          example 'ae1' for the revision 'ae1027a6acf'), or a decimal value
+          '+N' N being the number of revisions to execute from the current one.
+          """,
+)
+def downgrade(self: Task):
+    migrate(self, command.downgrade)
+
+
+@Db.subcommand(with_task_context=True)
+@argument("--db_label", "-d", type=str, default="default")
 @argument(
     "revision",
     type=str,
@@ -146,33 +238,22 @@ class ExecuteSQL(Command):
 )
 def upgrade(self: Task):
     """
-    Upgrade the Outflow database to given migration.
+    Upgrade the a database to given migration.
     """
-    revision = self.context.args.revision
 
-    version_locations = list()
-    for plugin_name in self.context.settings.PLUGINS:
-        location = Plugin.get_path(plugin_name) / "models" / "versions"
-        if location.is_dir():
-            version_locations.append(location.as_posix())
-
-    cfg = Config()
-
-    alembic_path = Path(outflow_alembic.__file__).parent.resolve().as_posix()
-
-    cfg.set_main_option("version_locations", " ".join(version_locations))
-    cfg.set_main_option("script_location", alembic_path)
-    cfg.set_main_option("output_encoding", "utf-8")
-
-    cfg.attributes["connection"] = self.context.db.admin_connection
-    logger.info("Calling alembic")
-
-    command.upgrade(cfg, revision)
+    migrate(self, command.upgrade)
 
 
 @Db.subcommand(with_task_context=True, allow_extra_args=True)
-@argument("plugin", type=str, default=None)
-def Makemigrations(self: Task):
+@argument(
+    "--plugin",
+    "-p",
+    type=str,
+    required=True,
+    help="Name of the plugin for which you want to generate the migrations",
+)
+@argument("--db_label", "-d", type=str, default="default")
+def MakeMigrations(self: Task):
     """A task to automatically generate migrations
     'alembic revision --autogenerate' is used to generate migrations.
     You have to manually edit the migration after being generated, because
@@ -180,41 +261,60 @@ def Makemigrations(self: Task):
     generate the schema creation. More info :
     http://alembic.zzzcomputing.com/en/latest/autogenerate.html#what-does-autogenerate-detect-and-what-does-it-not-detect
     """
-    # get the plugin to use
-    plugin = self.context.args.plugin
 
-    # check that it is valid
+    plugin = self.context.args.plugin
+    db_label = self.context.args.db_label
+
+    plugin_version_path = Plugin.get_path(plugin) / "models" / "versions" / db_label
+
+    # ensure the version directory exist
+    os.makedirs(plugin_version_path, exist_ok=True)
+
+    # get the plugin to use
+    if plugin == "outflow.management":
+        db_label = "default"
+
+        mng_plugin_version_path = (
+            Plugin.get_path("outflow.management") / "models" / "versions" / db_label
+        )
+        version_locations = [mng_plugin_version_path.resolve().as_posix()]
+    else:
+        version_locations = list()
+        # get all the previous versions associated with the given base
+        for plugin_name in self.context.settings.PLUGINS:
+            version_path = (
+                Plugin.get_path(plugin_name) / "models" / "versions" / db_label
+            )
+            if version_path.is_dir():
+                version_locations.append(version_path.resolve().as_posix())
+
+    # check that the plugin is valid
     Plugin.load(plugin)
 
-    version_locations = list()
-    for plugin_name in self.context.settings.PLUGINS:
-        location = Plugin.get_path(plugin_name, "models", "versions")
-        if Path(location).is_dir():
-            version_locations.append(location)
-
+    alembic_config_dict = get_alembic_config(db_label, self.context, plugin=plugin)
     cfg = Config()
 
-    alembic_path = Plugin.get_path("outflow", "db", "alembic")
+    for key, value in alembic_config_dict["main_options"].items():
+        cfg.set_main_option(key, value)
 
-    cfg.set_main_option("version_locations", " ".join(version_locations))
-    cfg.set_main_option("script_location", alembic_path)
-    cfg.set_main_option("output_encoding", "utf-8")
+    for key, value in alembic_config_dict["attributes"].items():
+        cfg.attributes[key] = value
 
-    cfg.attributes["connection"] = self.context.db.admin_connection
-    cfg.attributes["plugin"] = plugin
+    for key, value in alembic_config_dict["post_write_hooks"].items():
+        cfg.set_section_option("post_write_hooks", key, value)
 
     logger.info("Calling alembic revision")
 
     # used to pass arguments to alembic revision command
     # http://alembic.zzzcomputing.com/en/latest/api/commands.html#alembic.command.revision
     args = dict()
-    for arg in sys.argv[4:]:
+    for arg in self.context.extra_args:
         try:
             # Only parse keyword of the form (-)-key=val
             if "=" in arg:
                 s = arg.split("=")
             else:
-                logger.error(
+                logger.warning(
                     f"Input keyword {arg} can not be parsed and will be ignored, "
                     "please call extra alembic keywords using '='!"
                 )
@@ -235,17 +335,15 @@ def Makemigrations(self: Task):
     command.revision(
         cfg,
         autogenerate=True,
-        version_path=Plugin.get_path(plugin, "models", "versions"),
+        version_path=plugin_version_path.as_posix(),
         **args,
     )
 
-    # TODO have poppy.pop as dependency for any first migration of a plugin ?
-
 
 @Db.subcommand(description="Generate the database documentation of a plugin")
 @argument(
     "plugin_name",
-    help="The name of the plugin we want to generate the documentation of",
+    help="The name of the plugin for which we want to generate the documentation",
 )
 def GenDoc(plugin_name):
     """
@@ -286,7 +384,7 @@ def GenDoc(plugin_name):
             # Title of the section
             title = f"The table {table_name}\n"
             text += title
-            text += f"{'='*(len(title)-1)}\n"
+            text += f"{'=' * (len(title) - 1)}\n"
 
             # The docstring of the class representation of the table
             text += " ".join(
@@ -331,12 +429,11 @@ def GenDoc(plugin_name):
                 table_doc_dict.update({schema_name: text})
 
         for schema_name, text in table_doc_dict.items():
-
             schema_header = f"The '{schema_name}' schema\n"
 
-            f.write(f"{'*'*(len(schema_header)-1)}\n")
+            f.write(f"{'*' * (len(schema_header) - 1)}\n")
             f.write(schema_header)
-            f.write(f"{'*'*(len(schema_header)-1)}\n\n")
+            f.write(f"{'*' * (len(schema_header) - 1)}\n\n")
 
             f.write(table_doc_dict[schema_name])
 
