@@ -1,6 +1,4 @@
 # -*- coding: utf-8 -*-
-import sys
-
 from outflow.core.logging import logger
 
 
@@ -19,10 +17,6 @@ class BaseActor:
 
         set_plugins_loggers_config()
 
-        # needed when plugins are not installed but only in python path
-        if python_path is not None:
-            sys.path.extend(python_path)
-
     def update_pipeline_context_args(self, pipeline_args, extra_args):
         logger.debug(
             f"Update pipeline context '{self.pipeline_context}' with args '{pipeline_args}' and extra_args '{extra_args}'"
