@@ -2,7 +2,7 @@
 
 import ray
 from outflow.core.logging import logger
-from outflow.core.tasks.task_manager import TaskManager
+from outflow.ray.task_manager import RayTaskManager
 
 from .base_actor import BaseActor
 
@@ -13,7 +13,7 @@ class MainActor(BaseActor):
         logger.debug(
             f"Run pipeline with actor '{self}' and with pipeline context '{self.pipeline_context}'"
         )
-        task_manager = TaskManager()
+        task_manager = RayTaskManager()
 
         for task in task_list:
             task.workflow.set_context(self.pipeline_context)
