@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 import ray
-from outflow.core.actors import BaseActor
+
+from .base_actor import BaseActor
 
 
 @ray.remote
