@@ -4,7 +4,7 @@ from outflow.core.results import Results as CoreResults
 import ray
 
 
-class Results(CoreResults):
+class RayResults(CoreResults):
     def resolve(self, task_id):
         import ray
 
