@@ -23,14 +23,20 @@ class MapTask(Task):
         num_cpus=1,
         raise_exceptions=False
     ):
-
-        super().__init__()
-
+        super().__init__(auto_outputs=False)
         if outputs is None:
             self.outputs = {output_name: Target(output_name, type=List)}
         else:
             self.outputs = outputs
 
+        input_targets = [target for target in start.inputs.values()]
+        self.inputs = {
+            target.type.__name__[len(IterateOn.prefix) :]
+            if target.type.__name__.startswith(IterateOn.prefix)
+            else target.name: target
+            for target in input_targets
+        }
+
         if name is not None:
             self.name = name
 
@@ -38,8 +44,10 @@ class MapTask(Task):
 
         if end is None:
             self.start.terminating = True
+            self.end = self.start
         else:
             end.terminating = True
+            self.end = end
 
         if reduce_func is None:
             self.reduce = lambda x: {output_name: x}
